@@ -1,12 +1,12 @@
+from maleo.mixins.filter import Filters
+from maleo.mixins.sort import Sorts
 from maleo.mixins.parameter import (
-    Filters,
-    DataStatuses,
-    Sorts,
     Search,
     UseCache,
-    StatusUpdateAction,
 )
-from maleo.dtos.pagination import BaseFlexiblePagination, BaseStrictPagination
+from maleo.mixins.status import DataStatuses
+from .operation.action.status import StatusUpdateOperationAction
+from .pagination import BaseFlexiblePagination, BaseStrictPagination
 
 
 class ReadSingleQuery(
@@ -40,5 +40,5 @@ class ReadPaginatedMultipleQuery(
     pass
 
 
-class StatusUpdateBody(StatusUpdateAction):
+class StatusUpdateBody(StatusUpdateOperationAction):
     pass
