@@ -1,7 +1,21 @@
 from pydantic import BaseModel, Field
-from typing import Dict, Generic, List, Literal, Optional, Type, TypeVar, Union
-from maleo.dtos.data import DataPair, GenericDataT, DataT
-from maleo.dtos.descriptor import (
+from typing import (
+    Any,
+    Dict,
+    Generic,
+    List,
+    Literal,
+    Optional,
+    Type,
+    TypeVar,
+    Union,
+    overload,
+)
+from maleo.mixins.general import SuccessT, Success, CodeT, Descriptor
+from maleo.types.dict import StringToAnyDict
+from maleo.types.string import OptionalString
+from .data import DataPair, AnyDataT, ModelDataT
+from .error.descriptor import (
     ErrorDescriptor,
     BadRequestErrorDescriptor,
     UnauthorizedErrorDescriptor,
@@ -12,10 +26,30 @@ from maleo.dtos.descriptor import (
     UnprocessableEntityErrorDescriptor,
     TooManyRequestsErrorDescriptor,
     InternalServerErrorDescriptor,
-    DatabaseErrorDescriptor,
     NotImplementedErrorDescriptor,
     BadGatewayErrorDescriptor,
     ServiceUnavailableErrorDescriptor,
+)
+from .error.enums import Code as ErrorCode
+from .metadata import AnyMetadataT, ModelMetadataT
+from .pagination import OptionalPaginationT, PaginationT
+from .payload import (
+    Payload,
+    NoDataPayload,
+    SingleDataPayload,
+    CreateSingleDataPayload,
+    ReadSingleDataPayload,
+    UpdateSingleDataPayload,
+    DeleteSingleDataPayload,
+    OptionalSingleDataPayload,
+    MultipleDataPayload,
+    CreateMultipleDataPayload,
+    ReadMultipleDataPayload,
+    UpdateMultipleDataPayload,
+    DeleteMultipleDataPayload,
+    OptionalMultipleDataPayload,
+)
+from .success.descriptor import (
     SuccessDescriptor,
     AnyDataSuccessDescriptor,
     NoDataSuccessDescriptor,
@@ -32,49 +66,20 @@ from maleo.dtos.descriptor import (
     UpdateMultipleDataSuccessDescriptor,
     DeleteMultipleDataSuccessDescriptor,
 )
-from maleo.dtos.metadata import MetadataT
-from maleo.dtos.pagination import PaginationT, GenericPaginationT
-from maleo.dtos.payload import (
-    Payload,
-    NoDataPayload,
-    SingleDataPayload,
-    CreateSingleDataPayload,
-    ReadSingleDataPayload,
-    UpdateSingleDataPayload,
-    DeleteSingleDataPayload,
-    OptionalSingleDataPayload,
-    MultipleDataPayload,
-    CreateMultipleDataPayload,
-    ReadMultipleDataPayload,
-    UpdateMultipleDataPayload,
-    DeleteMultipleDataPayload,
-    OptionalMultipleDataPayload,
-)
-from maleo.enums.error import Code as ErrorCode
-from maleo.enums.success import Code as SuccessCode
-from maleo.mixins.general import SuccessT, Success, CodeT, Descriptor
-from maleo.types.base.any import OptionalAny
-from maleo.types.base.string import OptionalString
+from .success.enums import Code as SuccessCode
 
 
 class Response(
-    Payload[GenericDataT, GenericPaginationT, MetadataT],
+    Payload[AnyDataT, OptionalPaginationT, AnyMetadataT],
     Descriptor[CodeT],
     Success[SuccessT],
     BaseModel,
-    Generic[SuccessT, CodeT, GenericDataT, GenericPaginationT, MetadataT],
+    Generic[SuccessT, CodeT, AnyDataT, OptionalPaginationT, AnyMetadataT],
 ):
     pass
 
 
-ResponseT = TypeVar("ResponseT", bound=Response)
-
-
-class ResponseMixin(BaseModel, Generic[ResponseT]):
-    response: ResponseT = Field(..., description="Response")
-
-
-# Failure Response
+# Error Response
 class ErrorResponse(
     NoDataPayload[None],
     ErrorDescriptor,
@@ -84,10 +89,7 @@ class ErrorResponse(
     data: None = None
     pagination: None = None
     metadata: None = None
-    other: OptionalAny = "Please try again later or contact administrator"
-
-
-ErrorResponseT = TypeVar("ErrorResponseT", bound=ErrorResponse)
+    other: Any = "Please try again later or contact administrator"
 
 
 class BadRequestResponse(
@@ -153,13 +155,6 @@ class InternalServerErrorResponse(
     pass
 
 
-class DatabaseErrorResponse(
-    DatabaseErrorDescriptor,
-    ErrorResponse,
-):
-    pass
-
-
 class NotImplementedResponse(
     NotImplementedErrorDescriptor,
     ErrorResponse,
@@ -181,33 +176,285 @@ class ServiceUnavailableResponse(
     pass
 
 
-ERROR_RESPONSE_MAP: Dict[ErrorCode, Type[ErrorResponse]] = {
-    ErrorCode.BAD_REQUEST: BadRequestResponse,
-    ErrorCode.UNAUTHORIZED: UnauthorizedResponse,
-    ErrorCode.FORBIDDEN: ForbiddenResponse,
-    ErrorCode.NOT_FOUND: NotFoundResponse,
-    ErrorCode.METHOD_NOT_ALLOWED: MethodNotAllowedResponse,
-    ErrorCode.CONFLICT: ConflictResponse,
-    ErrorCode.UNPROCESSABLE_ENTITY: UnprocessableEntityResponse,
-    ErrorCode.TOO_MANY_REQUESTS: TooManyRequestsResponse,
-    ErrorCode.INTERNAL_SERVER_ERROR: InternalServerErrorResponse,
-    ErrorCode.DATABASE_ERROR: DatabaseErrorResponse,
-    ErrorCode.NOT_IMPLEMENTED: NotImplementedResponse,
-    ErrorCode.BAD_GATEWAY: BadGatewayResponse,
-    ErrorCode.SERVICE_UNAVAILABLE: ServiceUnavailableResponse,
-}
+AnyErrorResponseType = Union[
+    Type[BadRequestResponse],
+    Type[UnauthorizedResponse],
+    Type[ForbiddenResponse],
+    Type[NotFoundResponse],
+    Type[MethodNotAllowedResponse],
+    Type[ConflictResponse],
+    Type[UnprocessableEntityResponse],
+    Type[TooManyRequestsResponse],
+    Type[InternalServerErrorResponse],
+    Type[NotImplementedResponse],
+    Type[BadGatewayResponse],
+    Type[ServiceUnavailableResponse],
+]
+AnyErrorResponse = Union[
+    BadRequestResponse,
+    UnauthorizedResponse,
+    ForbiddenResponse,
+    NotFoundResponse,
+    MethodNotAllowedResponse,
+    ConflictResponse,
+    UnprocessableEntityResponse,
+    TooManyRequestsResponse,
+    InternalServerErrorResponse,
+    NotImplementedResponse,
+    BadGatewayResponse,
+    ServiceUnavailableResponse,
+]
+ErrorResponseT = TypeVar("ErrorResponseT", bound=AnyErrorResponse)
+
+
+class ErrorFactory:
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.BAD_REQUEST, 400],
+        /,
+    ) -> Type[BadRequestResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.UNAUTHORIZED, 401],
+        /,
+    ) -> Type[UnauthorizedResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.FORBIDDEN, 403],
+        /,
+    ) -> Type[ForbiddenResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.NOT_FOUND, 404],
+        /,
+    ) -> Type[NotFoundResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.METHOD_NOT_ALLOWED, 405],
+        /,
+    ) -> Type[MethodNotAllowedResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.CONFLICT, 409],
+        /,
+    ) -> Type[ConflictResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.UNPROCESSABLE_ENTITY, 422],
+        /,
+    ) -> Type[UnprocessableEntityResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.TOO_MANY_REQUESTS, 429],
+        /,
+    ) -> Type[TooManyRequestsResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.INTERNAL_SERVER_ERROR, 500],
+        /,
+    ) -> Type[InternalServerErrorResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.NOT_IMPLEMENTED, 501],
+        /,
+    ) -> Type[NotImplementedResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.BAD_GATEWAY, 502],
+        /,
+    ) -> Type[BadGatewayResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Literal[ErrorCode.SERVICE_UNAVAILABLE, 503],
+        /,
+    ) -> Type[ServiceUnavailableResponse]: ...
+    @overload
+    @staticmethod
+    def cls_from_code(
+        code: Union[ErrorCode, int],
+        /,
+    ) -> AnyErrorResponseType: ...
+    @staticmethod
+    def cls_from_code(
+        code: Union[ErrorCode, int],
+        /,
+    ) -> AnyErrorResponseType:
+        if code is ErrorCode.BAD_REQUEST or code == 400:
+            return BadRequestResponse
+        elif code is ErrorCode.UNAUTHORIZED or code == 401:
+            return UnauthorizedResponse
+        elif code is ErrorCode.FORBIDDEN or code == 403:
+            return ForbiddenResponse
+        elif code is ErrorCode.NOT_FOUND or code == 404:
+            return NotFoundResponse
+        elif code is ErrorCode.METHOD_NOT_ALLOWED or code == 405:
+            return MethodNotAllowedResponse
+        elif code is ErrorCode.CONFLICT or code == 409:
+            return ConflictResponse
+        elif code is ErrorCode.UNPROCESSABLE_ENTITY or code == 422:
+            return UnprocessableEntityResponse
+        elif code is ErrorCode.TOO_MANY_REQUESTS or code == 429:
+            return TooManyRequestsResponse
+        elif code is ErrorCode.INTERNAL_SERVER_ERROR or code == 500:
+            return InternalServerErrorResponse
+        elif code is ErrorCode.NOT_IMPLEMENTED or code == 501:
+            return NotImplementedResponse
+        elif code is ErrorCode.BAD_GATEWAY or code == 502:
+            return BadGatewayResponse
+        elif code is ErrorCode.SERVICE_UNAVAILABLE or code == 503:
+            return ServiceUnavailableResponse
+        raise ValueError(f"Unable to determine error response class for code: {code}")
+
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.BAD_REQUEST, 400],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> BadRequestResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.UNAUTHORIZED, 401],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> UnauthorizedResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.FORBIDDEN, 403],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> ForbiddenResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.NOT_FOUND, 404],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> NotFoundResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.METHOD_NOT_ALLOWED, 405],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> MethodNotAllowedResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.CONFLICT, 409],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> ConflictResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.UNPROCESSABLE_ENTITY, 422],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> UnprocessableEntityResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.TOO_MANY_REQUESTS, 429],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> TooManyRequestsResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.INTERNAL_SERVER_ERROR, 500],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> InternalServerErrorResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.NOT_IMPLEMENTED, 501],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> NotImplementedResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.BAD_GATEWAY, 502],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> BadGatewayResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Literal[ErrorCode.SERVICE_UNAVAILABLE, 503],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> ServiceUnavailableResponse: ...
+    @overload
+    @staticmethod
+    def from_code(
+        code: Union[ErrorCode, int],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> AnyErrorResponse: ...
+    @staticmethod
+    def from_code(
+        code: Union[ErrorCode, int],
+        *,
+        message: OptionalString = None,
+        description: OptionalString = None,
+        other: Any = None,
+    ) -> AnyErrorResponse:
+        obj = {}
+        if message is not None:
+            obj["message"] = message
+        if description is not None:
+            obj["description"] = description
+        if other is not None:
+            obj["other"] = other
+        return ErrorFactory.cls_from_code(code).model_validate(obj)
 
 
 OTHER_RESPONSES: Dict[
     Union[int, str],
-    Dict[
-        str,
-        Union[
-            str,
-            Type[ErrorResponse],
-            List[Type[ErrorResponse]],
-        ],
-    ],
+    StringToAnyDict,
 ] = {
     400: {
         "description": "Bad Request Response",
@@ -243,10 +490,7 @@ OTHER_RESPONSES: Dict[
     },
     500: {
         "description": "Internal Server Error Response",
-        "model": [
-            InternalServerErrorResponse,
-            DatabaseErrorResponse,
-        ],
+        "model": InternalServerErrorResponse,
     },
     501: {
         "description": "Not Implemented Response",
@@ -265,28 +509,25 @@ OTHER_RESPONSES: Dict[
 
 class SuccessResponse(
     SuccessDescriptor,
-    Response[Literal[True], SuccessCode, GenericDataT, GenericPaginationT, MetadataT],
-    Generic[GenericDataT, GenericPaginationT, MetadataT],
+    Response[Literal[True], SuccessCode, AnyDataT, OptionalPaginationT, AnyMetadataT],
+    Generic[AnyDataT, OptionalPaginationT, AnyMetadataT],
 ):
     success: Literal[True] = True
 
 
-SuccessResponseT = TypeVar("SuccessResponseT", bound=SuccessResponse)
-
-
 class AnyDataResponse(
     AnyDataSuccessDescriptor,
-    SuccessResponse[DataT, GenericPaginationT, MetadataT],
-    Generic[DataT, GenericPaginationT, MetadataT],
+    SuccessResponse[AnyDataT, OptionalPaginationT, AnyMetadataT],
+    Generic[AnyDataT, OptionalPaginationT, AnyMetadataT],
 ):
     pass
 
 
 class NoDataResponse(
-    NoDataPayload[MetadataT],
+    NoDataPayload[ModelMetadataT],
     NoDataSuccessDescriptor,
-    SuccessResponse[None, None, MetadataT],
-    Generic[MetadataT],
+    SuccessResponse[None, None, ModelMetadataT],
+    Generic[ModelMetadataT],
 ):
     data: None = None
     pagination: None = None
@@ -297,9 +538,9 @@ class NoDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "NoDataResponse[MetadataT]":
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "NoDataResponse[ModelMetadataT]":
         descriptor = NoDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
@@ -312,10 +553,10 @@ class NoDataResponse(
 
 
 class SingleDataResponse(
-    SingleDataPayload[DataT, MetadataT],
+    SingleDataPayload[ModelDataT, ModelMetadataT],
     SingleDataSuccessDescriptor,
-    SuccessResponse[DataT, None, MetadataT],
-    Generic[DataT, MetadataT],
+    SuccessResponse[ModelDataT, None, ModelMetadataT],
+    Generic[ModelDataT, ModelMetadataT],
 ):
     pagination: None = None
 
@@ -325,10 +566,10 @@ class SingleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        data: DataT,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "SingleDataResponse[DataT, MetadataT]":
+        data: ModelDataT,
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "SingleDataResponse[ModelDataT, ModelMetadataT]":
         descriptor = SingleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
@@ -342,10 +583,10 @@ class SingleDataResponse(
 
 
 class CreateSingleDataResponse(
-    CreateSingleDataPayload[DataT, MetadataT],
+    CreateSingleDataPayload[ModelDataT, ModelMetadataT],
     CreateSingleDataSuccessDescriptor,
-    SuccessResponse[DataPair[None, DataT], None, MetadataT],
-    Generic[DataT, MetadataT],
+    SuccessResponse[DataPair[None, ModelDataT], None, ModelMetadataT],
+    Generic[ModelDataT, ModelMetadataT],
 ):
     pagination: None = None
 
@@ -355,17 +596,17 @@ class CreateSingleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        data: DataT,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "CreateSingleDataResponse[DataT, MetadataT]":
+        data: ModelDataT,
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "CreateSingleDataResponse[ModelDataT, ModelMetadataT]":
         descriptor = CreateSingleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[None, DataT](
+            data=DataPair[None, ModelDataT](
                 old=None,
                 new=data,
             ),
@@ -375,10 +616,10 @@ class CreateSingleDataResponse(
 
 
 class ReadSingleDataResponse(
-    ReadSingleDataPayload[DataT, MetadataT],
+    ReadSingleDataPayload[ModelDataT, ModelMetadataT],
     ReadSingleDataSuccessDescriptor,
-    SuccessResponse[DataPair[DataT, None], None, MetadataT],
-    Generic[DataT, MetadataT],
+    SuccessResponse[DataPair[ModelDataT, None], None, ModelMetadataT],
+    Generic[ModelDataT, ModelMetadataT],
 ):
     pagination: None = None
 
@@ -388,17 +629,17 @@ class ReadSingleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        data: DataT,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "ReadSingleDataResponse[DataT, MetadataT]":
+        data: ModelDataT,
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "ReadSingleDataResponse[ModelDataT, ModelMetadataT]":
         descriptor = ReadSingleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[DataT, None](
+            data=DataPair[ModelDataT, None](
                 old=data,
                 new=None,
             ),
@@ -408,10 +649,10 @@ class ReadSingleDataResponse(
 
 
 class UpdateSingleDataResponse(
-    UpdateSingleDataPayload[DataT, MetadataT],
+    UpdateSingleDataPayload[ModelDataT, ModelMetadataT],
     UpdateSingleDataSuccessDescriptor,
-    SuccessResponse[DataPair[DataT, DataT], None, MetadataT],
-    Generic[DataT, MetadataT],
+    SuccessResponse[DataPair[ModelDataT, ModelDataT], None, ModelMetadataT],
+    Generic[ModelDataT, ModelMetadataT],
 ):
     pagination: None = None
 
@@ -421,18 +662,18 @@ class UpdateSingleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        old_data: DataT,
-        new_data: DataT,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "UpdateSingleDataResponse[DataT, MetadataT]":
+        old_data: ModelDataT,
+        new_data: ModelDataT,
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "UpdateSingleDataResponse[ModelDataT, ModelMetadataT]":
         descriptor = UpdateSingleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[DataT, DataT](
+            data=DataPair[ModelDataT, ModelDataT](
                 old=old_data,
                 new=new_data,
             ),
@@ -442,10 +683,10 @@ class UpdateSingleDataResponse(
 
 
 class DeleteSingleDataResponse(
-    DeleteSingleDataPayload[DataT, MetadataT],
+    DeleteSingleDataPayload[ModelDataT, ModelMetadataT],
     DeleteSingleDataSuccessDescriptor,
-    SuccessResponse[DataPair[DataT, None], None, MetadataT],
-    Generic[DataT, MetadataT],
+    SuccessResponse[DataPair[ModelDataT, None], None, ModelMetadataT],
+    Generic[ModelDataT, ModelMetadataT],
 ):
     pagination: None = None
 
@@ -455,17 +696,17 @@ class DeleteSingleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        data: DataT,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "DeleteSingleDataResponse[DataT, MetadataT]":
+        data: ModelDataT,
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "DeleteSingleDataResponse[ModelDataT, ModelMetadataT]":
         descriptor = DeleteSingleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[DataT, None](
+            data=DataPair[ModelDataT, None](
                 old=data,
                 new=None,
             ),
@@ -475,10 +716,10 @@ class DeleteSingleDataResponse(
 
 
 class OptionalSingleDataResponse(
-    OptionalSingleDataPayload[DataT, MetadataT],
+    OptionalSingleDataPayload[ModelDataT, ModelMetadataT],
     OptionalSingleDataSuccessDescriptor,
-    SuccessResponse[Optional[DataT], None, MetadataT],
-    Generic[DataT, MetadataT],
+    SuccessResponse[Optional[ModelDataT], None, ModelMetadataT],
+    Generic[ModelDataT, ModelMetadataT],
 ):
     pagination: None = None
 
@@ -488,10 +729,10 @@ class OptionalSingleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        data: Optional[DataT] = None,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "OptionalSingleDataResponse[DataT, MetadataT]":
+        data: Optional[ModelDataT] = None,
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "OptionalSingleDataResponse[ModelDataT, ModelMetadataT]":
         descriptor = OptionalSingleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
@@ -505,10 +746,10 @@ class OptionalSingleDataResponse(
 
 
 class MultipleDataResponse(
-    MultipleDataPayload[DataT, PaginationT, MetadataT],
+    MultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
     MultipleDataSuccessDescriptor,
-    SuccessResponse[List[DataT], PaginationT, MetadataT],
-    Generic[DataT, PaginationT, MetadataT],
+    SuccessResponse[List[ModelDataT], PaginationT, ModelMetadataT],
+    Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     @classmethod
     def new(
@@ -516,11 +757,11 @@ class MultipleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        data: List[DataT],
+        data: List[ModelDataT],
         pagination: PaginationT,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "MultipleDataResponse[DataT, PaginationT, MetadataT]":
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "MultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]":
         descriptor = MultipleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
@@ -535,10 +776,10 @@ class MultipleDataResponse(
 
 
 class CreateMultipleDataResponse(
-    CreateMultipleDataPayload[DataT, PaginationT, MetadataT],
+    CreateMultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
     CreateMultipleDataSuccessDescriptor,
-    SuccessResponse[DataPair[None, List[DataT]], PaginationT, MetadataT],
-    Generic[DataT, PaginationT, MetadataT],
+    SuccessResponse[DataPair[None, List[ModelDataT]], PaginationT, ModelMetadataT],
+    Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     @classmethod
     def new(
@@ -546,18 +787,18 @@ class CreateMultipleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        data: List[DataT],
+        data: List[ModelDataT],
         pagination: PaginationT,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "CreateMultipleDataResponse[DataT, PaginationT, MetadataT]":
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "CreateMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]":
         descriptor = CreateMultipleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[None, List[DataT]](
+            data=DataPair[None, List[ModelDataT]](
                 old=None,
                 new=data,
             ),
@@ -568,10 +809,10 @@ class CreateMultipleDataResponse(
 
 
 class ReadMultipleDataResponse(
-    ReadMultipleDataPayload[DataT, PaginationT, MetadataT],
+    ReadMultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
     ReadMultipleDataSuccessDescriptor,
-    SuccessResponse[DataPair[List[DataT], None], PaginationT, MetadataT],
-    Generic[DataT, PaginationT, MetadataT],
+    SuccessResponse[DataPair[List[ModelDataT], None], PaginationT, ModelMetadataT],
+    Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     @classmethod
     def new(
@@ -579,18 +820,18 @@ class ReadMultipleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        data: List[DataT],
+        data: List[ModelDataT],
         pagination: PaginationT,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "ReadMultipleDataResponse[DataT, PaginationT, MetadataT]":
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "ReadMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]":
         descriptor = ReadMultipleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[List[DataT], None](
+            data=DataPair[List[ModelDataT], None](
                 old=data,
                 new=None,
             ),
@@ -601,10 +842,12 @@ class ReadMultipleDataResponse(
 
 
 class UpdateMultipleDataResponse(
-    UpdateMultipleDataPayload[DataT, PaginationT, MetadataT],
+    UpdateMultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
     UpdateMultipleDataSuccessDescriptor,
-    SuccessResponse[DataPair[List[DataT], List[DataT]], PaginationT, MetadataT],
-    Generic[DataT, PaginationT, MetadataT],
+    SuccessResponse[
+        DataPair[List[ModelDataT], List[ModelDataT]], PaginationT, ModelMetadataT
+    ],
+    Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     @classmethod
     def new(
@@ -612,19 +855,19 @@ class UpdateMultipleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        old_data: List[DataT],
-        new_data: List[DataT],
+        old_data: List[ModelDataT],
+        new_data: List[ModelDataT],
         pagination: PaginationT,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "UpdateMultipleDataResponse[DataT, PaginationT, MetadataT]":
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "UpdateMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]":
         descriptor = UpdateMultipleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[List[DataT], List[DataT]](
+            data=DataPair[List[ModelDataT], List[ModelDataT]](
                 old=old_data,
                 new=new_data,
             ),
@@ -635,10 +878,10 @@ class UpdateMultipleDataResponse(
 
 
 class DeleteMultipleDataResponse(
-    DeleteMultipleDataPayload[DataT, PaginationT, MetadataT],
+    DeleteMultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
     DeleteMultipleDataSuccessDescriptor,
-    SuccessResponse[DataPair[List[DataT], None], PaginationT, MetadataT],
-    Generic[DataT, PaginationT, MetadataT],
+    SuccessResponse[DataPair[List[ModelDataT], None], PaginationT, ModelMetadataT],
+    Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     @classmethod
     def new(
@@ -646,18 +889,18 @@ class DeleteMultipleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        data: List[DataT],
+        data: List[ModelDataT],
         pagination: PaginationT,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "DeleteMultipleDataResponse[DataT, PaginationT, MetadataT]":
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "DeleteMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]":
         descriptor = DeleteMultipleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
             description=(
                 description if description is not None else descriptor.description
             ),
-            data=DataPair[List[DataT], None](
+            data=DataPair[List[ModelDataT], None](
                 old=data,
                 new=None,
             ),
@@ -668,10 +911,10 @@ class DeleteMultipleDataResponse(
 
 
 class OptionalMultipleDataResponse(
-    OptionalMultipleDataPayload[DataT, PaginationT, MetadataT],
+    OptionalMultipleDataPayload[ModelDataT, PaginationT, ModelMetadataT],
     OptionalMultipleDataSuccessDescriptor,
-    SuccessResponse[Optional[List[DataT]], PaginationT, MetadataT],
-    Generic[DataT, PaginationT, MetadataT],
+    SuccessResponse[Optional[List[ModelDataT]], PaginationT, ModelMetadataT],
+    Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     @classmethod
     def new(
@@ -679,11 +922,11 @@ class OptionalMultipleDataResponse(
         *,
         message: OptionalString = None,
         description: OptionalString = None,
-        data: Optional[List[DataT]],
+        data: Optional[List[ModelDataT]],
         pagination: PaginationT,
-        metadata: MetadataT = None,
-        other: OptionalAny = None,
-    ) -> "OptionalMultipleDataResponse[DataT, PaginationT, MetadataT]":
+        metadata: ModelMetadataT = None,
+        other: Any = None,
+    ) -> "OptionalMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]":
         descriptor = OptionalMultipleDataSuccessDescriptor()
         return cls(
             message=message if message is not None else descriptor.message,
@@ -695,3 +938,30 @@ class OptionalMultipleDataResponse(
             metadata=metadata,
             other=other,
         )
+
+
+AllSuccessResponse = Union[
+    AnyDataResponse[ModelDataT, OptionalPaginationT, ModelMetadataT],
+    NoDataResponse[ModelMetadataT],
+    SingleDataResponse[ModelDataT, ModelMetadataT],
+    CreateSingleDataResponse[ModelDataT, ModelMetadataT],
+    ReadSingleDataResponse[ModelDataT, ModelMetadataT],
+    UpdateSingleDataResponse[ModelDataT, ModelMetadataT],
+    DeleteSingleDataResponse[ModelDataT, ModelMetadataT],
+    OptionalSingleDataResponse[ModelDataT, ModelMetadataT],
+    MultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
+    CreateMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
+    ReadMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
+    UpdateMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
+    DeleteMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
+    OptionalMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
+]
+SuccessResponseT = TypeVar("SuccessResponseT", bound=AllSuccessResponse)
+
+
+AllResponse = Union[AnyErrorResponse, AllSuccessResponse]
+ResponseT = TypeVar("ResponseT", bound=AllResponse)
+
+
+class ResponseMixin(BaseModel, Generic[ResponseT]):
+    response: ResponseT = Field(..., description="Response")
